@@ -80,7 +80,7 @@ class RequestEvent(EventBase):
     message: str
 
     def __init__(self, *args, **kws):
-        super().__init__(args, kws)
+        super().__init__(*args, **kws)
         self.operate = None
 
     @property
